@@ -32,53 +32,6 @@ class Agreements:
         self._config = config
         self.conditions = Conditions(self._keeper)
 
-    def get(self, agreement_id):
-        """
-        Retrieve the agreement data of agreement_id.
-
-        :param agreement_id: id of the agreement, hex str
-        :return: AgreementValues instance -- a namedtuple with the following attributes:
-
-            did,
-            owner,
-            template_id,
-            condition_ids,
-            updated_by,
-            block_number_updated
-
-        """
-        return self._keeper.agreement_manager.get_agreement(agreement_id)
-
-    @staticmethod
-    def new():
-        return ServiceAgreement.create_new_agreement_id()
-
-    def sign(self, agreement_id, did, consumer_account, service_index):
-        """
-        Sign a service agreement.
-
-        :param agreement_id: 32 bytes identifier created by the consumer and will be used
-         on-chain for the executed agreement.
-        :param did: str representation fo the asset DID. Use this to retrieve the asset DDO.
-        :param consumer_account: Account instance of the consumer
-        :param service_index: int identifies the specific service in
-         the ddo to use in this agreement.
-        :return: signature
-        """
-        asset = self._asset_resolver.resolve(did)
-        service_agreement = asset.get_service_by_index(service_index)
-
-        publisher_address = self._keeper.did_registry.get_did_owner(asset.asset_id)
-        agreement_hash = service_agreement.get_service_agreement_hash(
-            agreement_id, asset.asset_id, consumer_account.address, publisher_address, self._keeper
-        )
-        signature = self._keeper.sign_hash(add_ethereum_prefix_and_hash_msg(agreement_hash),
-                                           consumer_account)
-        address = self._keeper.personal_ec_recover(agreement_hash, signature)
-        assert address == consumer_account.address
-        logger.debug(f'agreement-signature={signature}, agreement-hash={agreement_hash}')
-        return signature
-
     def prepare(self, did, consumer_account, service_index):
         """
 
@@ -88,13 +41,11 @@ class Agreements:
          the ddo to use in this agreement.
         :return: tuple (agreement_id: str, signature: hex str)
         """
-        agreement_id = self.new()
-        signature = self.sign(agreement_id, did, consumer_account, service_index)
+        agreement_id = ServiceAgreement.create_new_agreement_id()
+        signature = self._sign(agreement_id, did, consumer_account, service_index)
         return agreement_id, signature
 
-    def create(self, did, index, agreement_id,
-               service_agreement_signature, consumer_address,
-               account, auto_consume=False):
+    def create(self, did, index, agreement_id, consumer_address, account):
         """
         Execute the service agreement on-chain using keeper's ServiceAgreement contract.
 
@@ -109,12 +60,10 @@ class Agreements:
          the ddo to use in this agreement.
         :param agreement_id: 32 bytes identifier created by the consumer and will be used
          on-chain for the executed agreement.
-        :param service_agreement_signature: str the signed agreement message hash which includes
          conditions and their parameters values and other details of the agreement.
         :param consumer_address: ethereum account address of consumer, hex str
         :param account: Account instance creating the agreement. Can be either the
             consumer, publisher or provider
-        :param auto_consume: bool
         :return: dict the `executeAgreement` transaction receipt
         """
         assert consumer_address and Web3Provider.get_web3().isChecksumAddress(
@@ -154,147 +103,6 @@ class Agreements:
                 f'Service agreement {agreement_id} already exists, cannot reuse '
                 f'the same agreement id.')
 
-        if consumer_address != account.address:
-            if not self._verify_service_agreement_signature(
-                    did, agreement_id, index,
-                    consumer_address, service_agreement_signature,
-                    ddo=asset
-            ):
-                raise InvalidServiceAgreementSignature(
-                    f'Verifying consumer signature failed: '
-                    f'signature {service_agreement_signature}, '
-                    f'consumerAddress {consumer_address}'
-                )
-
-        publisher_address = Web3Provider.get_web3().toChecksumAddress(asset.publisher)
-        condition_ids = service_agreement.generate_agreement_condition_ids(
-            agreement_id, asset_id, consumer_address, publisher_address, self._keeper)
-
-        time_locks = service_agreement.conditions_timelocks
-        time_outs = service_agreement.conditions_timeouts
-        if service_agreement.get_price() > self._keeper.token.get_token_balance(consumer_address):
-            return Exception(
-                f'The consumer balance is '
-                f'{self._keeper.token.get_token_balance(consumer_address)}. '
-                f'This balance is lower that the asset price {service_agreement.get_price()}.')
-        success = agreement_template.create_agreement(
-            agreement_id,
-            asset_id,
-            condition_ids,
-            time_locks,
-            time_outs,
-            consumer_address,
-            account
-        )
-        ## TODO CHECK THIS FOR THE OTHER TEMPLATE
-        if not success:
-            # success is based on tx receipt which is not reliable.
-            # So we check on-chain directly to see if agreement_id is there
-            consumer = self._keeper.escrow_access_secretstore_template.get_agreement_consumer(
-                agreement_id)
-            if consumer:
-                success = True
-            else:
-                event_log = self._keeper.escrow_access_secretstore_template \
-                    .subscribe_agreement_created(
-                    agreement_id, 15, None, (), wait=True
-                )
-                success = event_log is not None
-
-        if success:
-            logger.info(f'Service agreement {agreement_id} created successfully.')
-        else:
-            logger.info(f'Create agreement "{agreement_id}" failed.')
-            self._log_agreement_info(
-                asset, service_agreement, agreement_id, service_agreement_signature,
-                consumer_address, account, condition_ids
-            )
-        publisher_address = Web3Provider.get_web3().toChecksumAddress(asset.publisher)
-        if success:
-            # subscribe to events related to this agreement_id
-            if consumer_address == account.address:
-                from_block = Web3Provider.get_web3().eth.blockNumber - 10
-                self._process_consumer_agreement_events(
-                    agreement_id, did, service_agreement, account,
-                    condition_ids, publisher_address,
-                    from_block, auto_consume, service_agreement.type
-                )
-        return success
-
-    def create_direct(self, did, index, agreement_id,
-                      service_agreement_signature, consumer_address,
-                      account):
-        """
-        Execute the service agreement on-chain using keeper's ServiceAgreement contract.
-
-        The on-chain executeAgreement method requires the following arguments:
-        templateId, signature, consumer, hashes, timeouts, serviceAgreementId, did.
-        `agreement_message_hash` is necessary to verify the signature.
-        The consumer `signature` includes the conditions timeouts and parameters values which
-        is usedon-chain to verify that the values actually match the signed hashes.
-
-        :param did: str representation fo the asset DID. Use this to retrieve the asset DDO.
-        :param index: str identifies the specific service in
-         the ddo to use in this agreement.
-        :param agreement_id: 32 bytes identifier created by the consumer and will be used
-         on-chain for the executed agreement.
-        :param service_agreement_signature: str the signed agreement message hash which includes
-         conditions and their parameters values and other details of the agreement.
-        :param consumer_address: ethereum account address of consumer, hex str
-        :param account: Account instance creating the agreement. Can be either the
-            consumer, publisher or provider
-        :param auto_consume: bool
-        :return: dict the `executeAgreement` transaction receipt
-        """
-        assert consumer_address and Web3Provider.get_web3().isChecksumAddress(
-            consumer_address), f'Invalid consumer address {consumer_address}'
-        assert account.address in self._keeper.accounts, \
-            f'Unrecognized account address {account.address}'
-
-        agreement_template_approved = self._keeper.template_manager.is_template_approved(
-            self._keeper.escrow_access_secretstore_template.address)
-        agreement_exec_template_approved = self._keeper.template_manager.is_template_approved(
-            self._keeper.escrow_compute_execution_template.address)
-        if not agreement_template_approved:
-            msg = (f'The EscrowAccessSecretStoreTemplate contract at address '
-                   f'{self._keeper.escrow_access_secretstore_template.address} is not '
-                   f'approved and cannot be used for creating service agreements.')
-            logger.warning(msg)
-            raise InvalidAgreementTemplate(msg)
-        if not agreement_exec_template_approved:
-            msg = (f'The EscroComputeExecutionTemplate contract at address '
-                   f'{self._keeper.agreement_exec_template_approved.address} is not '
-                   f'approved and cannot be used for creating service agreements.')
-            logger.warning(msg)
-            raise InvalidAgreementTemplate(msg)
-
-        asset = self._asset_resolver.resolve(did)
-        asset_id = asset.asset_id
-        service_agreement = asset.get_service_by_index(index)
-        if service_agreement.type == ServiceTypes.ASSET_ACCESS:
-            agreement_template = self._keeper.escrow_access_secretstore_template
-        elif service_agreement.type == ServiceTypes.CLOUD_COMPUTE:
-            agreement_template = self._keeper.escrow_compute_execution_template
-        else:
-            raise Exception('The agreement could not be created. Review the index of your service.')
-
-        if agreement_template.get_agreement_consumer(agreement_id) != '0x0000000000000000000000000000000000000000':
-            raise ServiceAgreementExists(
-                f'Service agreement {agreement_id} already exists, cannot reuse '
-                f'the same agreement id.')
-
-        if consumer_address != account.address:
-            if not self._verify_service_agreement_signature(
-                    did, agreement_id, index,
-                    consumer_address, service_agreement_signature,
-                    ddo=asset
-            ):
-                raise InvalidServiceAgreementSignature(
-                    f'Verifying consumer signature failed: '
-                    f'signature {service_agreement_signature}, '
-                    f'consumerAddress {consumer_address}'
-                )
-
         publisher_address = Web3Provider.get_web3().toChecksumAddress(asset.publisher)
         condition_ids = service_agreement.generate_agreement_condition_ids(
             agreement_id, asset_id, consumer_address, publisher_address, self._keeper)
@@ -319,6 +127,79 @@ class Agreements:
             self.conditions.lock_reward(agreement_id, service_agreement.get_price(), account)
         return self._is_condition_fulfilled(agreement_id, 'lockReward')
 
+    def status(self, agreement_id):
+        """
+        Get the status of a service agreement.
+
+        :param agreement_id: id of the agreement, hex str
+        :return: dict with condition status of each of the agreement's conditions or None if the
+        agreement is invalid.
+        """
+        condition_ids = self._keeper.agreement_manager.get_agreement(agreement_id).condition_ids
+        result = {"agreementId": agreement_id}
+        conditions = dict()
+        for i in condition_ids:
+            conditions[self._keeper.get_condition_name_by_address(
+                self._keeper.condition_manager.get_condition(
+                    i).type_ref)] = self._keeper.condition_manager.get_condition_state(i)
+        result["conditions"] = conditions
+        return result
+
+    def is_access_granted(self, agreement_id, did, consumer_address):
+        """
+        Check permission for the agreement.
+
+        Verify on-chain that the `consumer_address` has permission to access the given asset `did`
+        according to the `agreement_id`.
+
+        :param agreement_id: id of the agreement, hex str
+        :param did: DID, str
+        :param consumer_address: ethereum account address of consumer, hex str
+        :return: bool True if user has permission
+        """
+        agreement_consumer = self._keeper.escrow_access_secretstore_template.get_agreement_consumer(
+            agreement_id)
+
+        if agreement_consumer is None:
+            return False
+
+        if agreement_consumer != consumer_address:
+            logger.warning(f'Invalid consumer address {consumer_address} and/or '
+                           f'service agreement id {agreement_id} (did {did})'
+                           f', agreement consumer is {agreement_consumer}')
+            return False
+
+        document_id = did_to_id(did)
+        return self._keeper.access_secret_store_condition.check_permissions(
+            document_id, consumer_address
+        )
+
+    def _sign(self, agreement_id, did, consumer_account, service_index):
+        """
+        Sign a service agreement.
+
+        :param agreement_id: 32 bytes identifier created by the consumer and will be used
+         on-chain for the executed agreement.
+        :param did: str representation fo the asset DID. Use this to retrieve the asset DDO.
+        :param consumer_account: Account instance of the consumer
+        :param service_index: int identifies the specific service in
+         the ddo to use in this agreement.
+        :return: signature
+        """
+        asset = self._asset_resolver.resolve(did)
+        service_agreement = asset.get_service_by_index(service_index)
+
+        publisher_address = self._keeper.did_registry.get_did_owner(asset.asset_id)
+        agreement_hash = service_agreement.get_service_agreement_hash(
+            agreement_id, asset.asset_id, consumer_account.address, publisher_address, self._keeper
+        )
+        signature = self._keeper.sign_hash(add_ethereum_prefix_and_hash_msg(agreement_hash),
+                                           consumer_account)
+        address = self._keeper.personal_ec_recover(agreement_hash, signature)
+        assert address == consumer_account.address
+        logger.debug(f'agreement-signature={signature}, agreement-hash={agreement_hash}')
+        return signature
+
     def _is_condition_fulfilled(self, agreement_id, condition_type):
         # TODO move this method to the contracts-lib-py
         max_retries = 5
@@ -413,35 +294,6 @@ class Agreements:
             f'\n  publisher ether balance: {publisher_ether_balance}'
         )
 
-    def is_access_granted(self, agreement_id, did, consumer_address):
-        """
-        Check permission for the agreement.
-
-        Verify on-chain that the `consumer_address` has permission to access the given asset `did`
-        according to the `agreement_id`.
-
-        :param agreement_id: id of the agreement, hex str
-        :param did: DID, str
-        :param consumer_address: ethereum account address of consumer, hex str
-        :return: bool True if user has permission
-        """
-        agreement_consumer = self._keeper.escrow_access_secretstore_template.get_agreement_consumer(
-            agreement_id)
-
-        if agreement_consumer is None:
-            return False
-
-        if agreement_consumer != consumer_address:
-            logger.warning(f'Invalid consumer address {consumer_address} and/or '
-                           f'service agreement id {agreement_id} (did {did})'
-                           f', agreement consumer is {agreement_consumer}')
-            return False
-
-        document_id = did_to_id(did)
-        return self._keeper.access_secret_store_condition.check_permissions(
-            document_id, consumer_address
-        )
-
     def _verify_service_agreement_signature(self, did, agreement_id, service_index,
                                             consumer_address, signature, ddo=None):
         """
@@ -484,20 +336,19 @@ class Agreements:
         self._keeper.token.token_approve(self._keeper.payment_conditions.address, amount,
                                          consumer_account)
 
-    def status(self, agreement_id):
+    def _get_agreement(self, agreement_id):
         """
-        Get the status of a service agreement.
+        Retrieve the agreement data of agreement_id.
 
         :param agreement_id: id of the agreement, hex str
-        :return: dict with condition status of each of the agreement's conditions or None if the
-        agreement is invalid.
+        :return: AgreementValues instance -- a namedtuple with the following attributes:
+
+            did,
+            owner,
+            template_id,
+            condition_ids,
+            updated_by,
+            block_number_updated
+
         """
-        condition_ids = self._keeper.agreement_manager.get_agreement(agreement_id).condition_ids
-        result = {"agreementId": agreement_id}
-        conditions = dict()
-        for i in condition_ids:
-            conditions[self._keeper.get_condition_name_by_address(
-                self._keeper.condition_manager.get_condition(
-                    i).type_ref)] = self._keeper.condition_manager.get_condition_state(i)
-        result["conditions"] = conditions
-        return result
+        return self._keeper.agreement_manager.get_agreement(agreement_id)
