@@ -3,12 +3,13 @@ import json
 import logging
 import os
 
+from common_utils_py.agreements.service_agreement import ServiceAgreement
 from common_utils_py.agreements.service_factory import ServiceDescriptor, ServiceFactory
 from common_utils_py.agreements.service_types import ServiceAuthorizationTypes, ServiceTypes
 from common_utils_py.ddo.ddo import DDO
 from common_utils_py.ddo.metadata import MetadataMain
 from common_utils_py.ddo.public_key_rsa import PUBLIC_KEY_TYPE_RSA
-from common_utils_py.did import DID, did_to_id, did_to_id_bytes
+from common_utils_py.did import DID, did_to_id, did_to_id_bytes, convert_to_bytes
 from common_utils_py.exceptions import (
     DIDAlreadyExist,
 )
@@ -53,7 +54,7 @@ class Assets:
     def create(self, metadata, publisher_account,
                service_descriptors=None, providers=None,
                authorization_type=ServiceAuthorizationTypes.PSK_RSA, use_secret_store=False,
-               activity_id=None, attributes=None):
+               activity_id=None, attributes=None, asset_rewards={"_amounts": [], "_receivers": []}):
         """
         Register an asset in both the keeper's DIDRegistry (on-chain) and in the Metadata store.
 
@@ -71,6 +72,7 @@ class Assets:
             encrypting urls (Uses Gateway provider service if set to False)
         :param activity_id: identifier of the activity creating the new entity
         :param attributes: attributes associated with the action
+        :param asset_rewards: rewards distribution including the amounts and the receivers
         :return: DDO instance
         """
         assert isinstance(metadata, dict), f'Expected metadata of type dict, got {type(metadata)}'
@@ -86,7 +88,7 @@ class Assets:
                                                                               ddo_service_endpoint)
         if metadata_copy['main']['type'] == 'dataset' or metadata_copy['main'][
             'type'] == 'algorithm':
-            access_service_attributes = self._build_access(metadata_copy, publisher_account)
+            access_service_attributes = self._build_access(metadata_copy, publisher_account, asset_rewards)
             if not service_descriptors:
                 if authorization_type == ServiceAuthorizationTypes.PSK_RSA:
                     service_descriptors = [ServiceDescriptor.authorization_service_descriptor(
@@ -258,7 +260,7 @@ class Assets:
             return None
         return ddo
 
-    def create_compute(self, metadata, publisher_account,
+    def create_compute(self, metadata, publisher_account, asset_rewards={"_amounts": [], "_receivers": []},
                service_descriptors=None, providers=None,
                authorization_type=ServiceAuthorizationTypes.PSK_RSA, use_secret_store=False):
         """
@@ -267,6 +269,7 @@ class Assets:
 
         :param metadata: dict conforming to the Metadata accepted by Nevermined Protocol.
         :param publisher_account: Account of the publisher registering this asset
+        :param asset_rewards: Asset rewards distribution including amounts and receivers
         :param service_descriptors: list of ServiceDescriptor tuples of length 2.
             The first item must be one of ServiceTypes and the second
             item is a dict of parameters and values required by the service
@@ -283,7 +286,7 @@ class Assets:
         metadata_copy = copy.deepcopy(metadata)
         gateway = GatewayProvider.get_gateway()
 
-        compute_service_attributes = self._build_compute(metadata_copy, publisher_account)
+        compute_service_attributes = self._build_compute(metadata_copy, publisher_account, asset_rewards)
         service_descriptor = ServiceDescriptor.compute_service_descriptor(
             compute_service_attributes, gateway.get_execute_endpoint(self._config))
 
@@ -291,7 +294,6 @@ class Assets:
             providers=providers, authorization_type=authorization_type,
             use_secret_store=use_secret_store)
 
-
     def retire(self, did):
         """
         Retire this did of Metadata
@@ -354,40 +356,13 @@ class Assets:
         return [DDO(dictionary=ddo_dict) for ddo_dict in
                 metadata_provider.query_search(query, sort, offset, page)['results']]
 
-    def order(self, did, index, consumer_account, auto_consume=False):
-        """
-        Place order by directly creating an SEA (agreement) on-chain.
-
-        :param did: str starting with the prefix `did:nv:` and followed by the asset id which is
-        a hex str
-        :param index: str the service definition id identifying a specific
-        service in the DDO (DID document)
-        :param consumer_account: Account instance of the consumer
-        :param auto_consume: boolean
-        :return: agreement_id the service agreement id (can be used to query
-            the nevermined-contracts for the status of the service agreement)
-        """
-        agreement_id = self._agreements.new()
+    def order(self, did, index, consumer_account, account):
+        agreement_id = ServiceAgreement.create_new_agreement_id()
         logger.debug(f'about to request create agreement: {agreement_id}')
         self._agreements.create(
             did,
             index,
             agreement_id,
-            None,
-            consumer_account.address,
-            consumer_account,
-            auto_consume=auto_consume
-        )
-        return agreement_id
-
-    def order_direct(self, did, index, consumer_account, account):
-        agreement_id = self._agreements.new()
-        logger.debug(f'about to request create agreement: {agreement_id}')
-        self._agreements.create_direct(
-            did,
-            index,
-            agreement_id,
-            None,
             consumer_account.address,
             account
         )
@@ -513,9 +488,6 @@ class Assets:
         :param owner_address: ethereum address of owner/publisher, hex-str
         :return: list of dids
         """
-        # return [k for k, v in self._get_metadata_provider(self._metadata_url).list_assets_ddo(
-        # ).items() if
-        #         v['proof']['creator'] == owner_address]
         return self._keeper.did_registry.get_owner_asset_ids(owner_address)
 
     def consumer_assets(self, consumer_address):
@@ -602,6 +574,45 @@ class Assets:
             self._config
         )
 
+    def mint(self, did, amount, account):
+        """
+        Mint an amount of nfts.
+        :param did: the id of an asset on-chain, hex str
+        :param amount: amount of nft to be minted, int
+        :param account: Account executing the action
+        """
+        return self._keeper.did_registry.mint(convert_to_bytes(did), amount, account)
+
+    def burn(self, did, amount, account):
+        """
+        Burn an amount of nfts.
+        :param did: the id of an asset on-chain, hex str
+        :param amount: amount of nft to be burnt, int
+        :param account: Account executing the action
+        """
+        return self._keeper.did_registry.burn(convert_to_bytes(did), amount, account)
+
+    def transfer_nft(self, did, address, amount, account):
+        """
+        Transfer nft to another address. Return true if successful
+
+        :param did: the id of an asset on-chain, hex str
+        :param address: ethereum account address, hex str
+        :param amount: amount of nft to be transfer, int
+        :param account: Account executing the action
+
+        """
+        return self._keeper.did_registry.transfer_nft(did_to_id(did), address, amount, account)
+
+    def balance(self, address, did):
+        """
+        Return nft balance.
+
+        :param address: ethereum account address, hex str
+        :param did: the id of an asset on-chain, hex str
+        """
+        return self._keeper.did_registry.balance(address, convert_to_bytes(did))
+
     @staticmethod
     def _build_authorization(authorization_type, public_key=None, threshold=None):
         authorization = dict()
@@ -614,23 +625,27 @@ class Assets:
         return authorization
 
     @staticmethod
-    def _build_access(metadata, publisher_account):
+    def _build_access(metadata, publisher_account, asset_rewards):
         return {"main": {
             "name": "dataAssetAccessServiceAgreement",
             "creator": publisher_account.address,
             "price": metadata[MetadataMain.KEY]['price'],
             "timeout": 3600,
-            "datePublished": metadata[MetadataMain.KEY]['dateCreated']
+            "datePublished": metadata[MetadataMain.KEY]['dateCreated'],
+            "_amounts": asset_rewards["_amounts"],
+            "_receivers": asset_rewards["_receivers"]
         }}
 
-    def _build_compute(self, metadata, publisher_account):
+    def _build_compute(self, metadata, publisher_account, asset_rewards):
         return {"main": {
             "name": "dataAssetComputeServiceAgreement",
             "creator": publisher_account.address,
             "datePublished": metadata[MetadataMain.KEY]['dateCreated'],
             "price": metadata[MetadataMain.KEY]['price'],
             "timeout": 86400,
-            "provider": self._build_provider_config()
+            "provider": self._build_provider_config(),
+            "_amounts": asset_rewards["_amounts"],
+            "_receivers": asset_rewards["_receivers"]
         }
         }
 
