@@ -7,17 +7,18 @@ from contracts_lib_py.web3_provider import Web3Provider
 from nevermined_sdk_py.assets.asset_consumer import AssetConsumer
 from nevermined_sdk_py.assets.asset_executor import AssetExecutor
 from nevermined_sdk_py.config_provider import ConfigProvider
+from nevermined_sdk_py.faucet.faucet import Faucet
 from nevermined_sdk_py.nevermined.accounts import Accounts
 from nevermined_sdk_py.nevermined.agreements import Agreements
 from nevermined_sdk_py.nevermined.assets import Assets
 from nevermined_sdk_py.nevermined.auth import Auth
 from nevermined_sdk_py.nevermined.keeper import NeverminedKeeper as Keeper
+from nevermined_sdk_py.nevermined.provenance import Provenance
 from nevermined_sdk_py.nevermined.providers import Providers
 from nevermined_sdk_py.nevermined.secret_store import SecretStore
 from nevermined_sdk_py.nevermined.services import Services
 from nevermined_sdk_py.nevermined.templates import Templates
 from nevermined_sdk_py.nevermined.tokens import Tokens
-from nevermined_sdk_py.nevermined.provenance import Provenance
 
 CONFIG_FILE_ENVIRONMENT_NAME = 'CONFIG_FILE'
 
@@ -31,7 +32,7 @@ class Nevermined:
         """
         Initialize Nevermined class.
            >> # Make a new Nevermined instance
-           >> ocean = Nevermined({...})
+           >> nevermined = Nevermined({...})
 
         This class provides the main top-level functions in nevermined protocol:
          * Publish assets metadata and associated services
@@ -40,10 +41,10 @@ class Nevermined:
             * The DID is registered on-chain with a URL of the metadata store
               to retrieve the DDO from
 
-            >> ddo = ocean.assets.create(metadata, publisher_account)
+            >> ddo = nevermined.assets.create(metadata, publisher_account)
 
          * Discover/Search assets via the current configured metadata store.
-            >> assets_list = ocean.assets.search('search text')
+            >> assets_list = nevermined.assets.search('search text')
 
          * Purchase asset services by choosing a service agreement from the
            asset's DDO. Purchase goes through the service agreements interface
@@ -52,7 +53,7 @@ class Nevermined:
            definition:
 
            >> service_def_id = ddo.get_service(ServiceTypes.ASSET_ACCESS).service_definition_id
-           >> service_agreement_id = ocean.assets.order(did, service_def_id, consumer_account)
+           >> service_agreement_id = nevermined.assets.order(did, service_def_id, consumer_account)
 
         An instance of Nevermined is parameterized by a `Config` instance.
 
@@ -86,8 +87,7 @@ class Nevermined:
 
         # Initialize the public sub-modules
         self.tokens = Tokens(self._keeper)
-        self.accounts = Accounts(self._keeper, self._config, self.tokens)
-        self.secret_store = SecretStore(self._config)
+        self.accounts = Accounts(self._keeper, self._config, self.tokens, Faucet)
         self.templates = Templates(
             self._keeper,
             config
@@ -102,6 +102,7 @@ class Nevermined:
             self._config
         )
         self.services = Services()
+        self.secret_store = SecretStore(self._config)
         self.providers = Providers(self._keeper, self._did_resolver, self._config)
         self.auth = Auth(self._keeper, self._config.storage_path)
         self.provenance = Provenance(self._keeper, self._config)
