@@ -206,7 +206,7 @@ def test_assets_consumed(publisher_instance, consumer_instance, ddo_sample):
             agr_id, did, cons_address, account)
 
     agreement_id = consumer_instance.assets.order(
-        asset.did, sa.index, acct)
+        asset.did, sa.index, acct, acct)
     keeper.lock_reward_condition.subscribe_condition_fulfilled(
         agreement_id,
         15,
@@ -264,7 +264,11 @@ def test_assets_workflow(publisher_instance, workflow_ddo):
 
 def test_assets_compute(publisher_instance, metadata):
     publisher = publisher_instance.main_account
-    ddo = publisher_instance.assets.create_compute(metadata, publisher)
+    asset_rewards = {
+        "_amounts": ["10", "2"],
+        "_receivers": ["0x00Bd138aBD70e2F00903268F3Db08f2D25677C9e", "0x068ed00cf0441e4829d9784fcbe7b9e26d4bd8d0"]
+    }
+    ddo = publisher_instance.assets.create_compute(metadata, publisher, asset_rewards=asset_rewards)
     assert ddo
     publisher_instance.assets.retire(ddo.did)
 
@@ -314,7 +318,7 @@ def test_execute_workflow(publisher_instance_no_init, consumer_instance_no_init,
     # order compute asset
     service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
     sa = ServiceAgreement.from_service_dict(service.as_dictionary())
-    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer)
+    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer, consumer)
 
     keeper = Keeper.get_instance()
     event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
@@ -352,7 +356,7 @@ def test_compute_status(publisher_instance_no_init, consumer_instance_no_init, m
     # order compute asset
     service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
     sa = ServiceAgreement.from_service_dict(service.as_dictionary())
-    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer)
+    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer, consumer)
 
     keeper = Keeper.get_instance()
     event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
@@ -393,7 +397,7 @@ def test_compute_logs(publisher_instance_no_init, consumer_instance_no_init, met
     # order compute asset
     service = ddo_computing.get_service(service_type=ServiceTypes.CLOUD_COMPUTE)
     sa = ServiceAgreement.from_service_dict(service.as_dictionary())
-    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer)
+    agreement_id = consumer_instance_no_init.assets.order(ddo_computing.did, sa.index, consumer, consumer)
 
     keeper = Keeper.get_instance()
     event = keeper.lock_reward_condition.subscribe_condition_fulfilled(
@@ -413,6 +417,7 @@ def test_compute_logs(publisher_instance_no_init, consumer_instance_no_init, met
     publisher_instance_no_init.assets.retire(ddo_algorithm.did)
     publisher_instance_no_init.assets.retire(workflow_ddo.did)
 
+
 def test_agreement_direct(publisher_instance, consumer_instance, metadata):
     publisher_account = publisher_instance.main_account
     consumer_account = consumer_instance.main_account
@@ -420,7 +425,7 @@ def test_agreement_direct(publisher_instance, consumer_instance, metadata):
                                                    providers=[
                                                        '0x068Ed00cF0441e4829D9784fCBe7b9e26D4BD8d0'])
 
-    agreement_id = consumer_instance.assets.order_direct(ddo.did,
+    agreement_id = consumer_instance.assets.order(ddo.did,
                                                                  ServiceTypesIndices.DEFAULT_ACCESS_INDEX,
                                                                  consumer_account,
                                                                  consumer_account
@@ -441,3 +446,23 @@ def test_agreement_direct(publisher_instance, consumer_instance, metadata):
     assert publisher_instance.agreements.is_access_granted(agreement_id, ddo.did,
                                                                    consumer_account.address)
     publisher_instance.assets.retire(ddo.did)
+
+
+def test_nfts(publisher_instance, metadata):
+    publisher = publisher_instance.main_account
+    someone_address = "0x00a329c0648769A73afAc7F9381E08FB43dBEA72"
+    ddo = publisher_instance.assets.create(metadata, publisher)
+
+    balance = publisher_instance.assets.balance(publisher.address, ddo.did)
+    assert balance == 1
+    balance_consumer = publisher_instance.assets.balance(someone_address, ddo.did)
+    assert balance_consumer == 0
+
+    publisher_instance.assets.mint(ddo.did, 10, account=publisher)
+    assert balance + 10 == publisher_instance.assets.balance(publisher.address, ddo.did)
+    assert publisher_instance.assets.transfer_nft(ddo.did, someone_address, 1, publisher)
+    assert publisher_instance.assets.balance(publisher.address, ddo.did) == 10
+    assert publisher_instance.assets.balance(someone_address, ddo.did) == balance_consumer + 1
+    publisher_instance.assets.burn(ddo.did, 9, account=publisher)
+    assert balance == publisher_instance.assets.balance(publisher.address, ddo.did)
+    publisher_instance.assets.retire(ddo.did)
\ No newline at end of file
