@@ -126,8 +126,12 @@ def get_computing_ddo():
 
 def get_registered_ddo(nevermined_instance, account):
     metadata = get_metadata()
+    asset_rewards = {
+        "_amounts": ["10", "2"],
+        "_receivers": ["0x00Bd138aBD70e2F00903268F3Db08f2D25677C9e", "0x068ed00cf0441e4829d9784fcbe7b9e26d4bd8d0"]
+    }
     metadata['main']['files'][0]['checksum'] = str(uuid.uuid4())
-    ddo = nevermined_instance.assets.create(metadata, account)
+    ddo = nevermined_instance.assets.create(metadata, account, asset_rewards=asset_rewards)
     return ddo
 
 
